@@ -66,8 +66,11 @@ def crc24_ble(data, deg_poly=0x65B, init_val=0x555555):
     return reverse_bits((crc).to_bytes(3, "big"))
 
 
-BLE_FREQ = (2, 26, 80,)
-"""The BLE channel number is different from the nRF channel number."""
+BLE_FREQ = (
+    2,
+    26,
+    80,
+)  #: The BLE channel number is different from the nRF channel number.
 
 
 class FakeBLE(RF24):
@@ -79,7 +82,6 @@ class FakeBLE(RF24):
         self._show_dbm = False
         self._ble_name = None
         self._mac = urandom(6)
-        self._to_android = 0x42
         self._config = self._config & 3 | 0x10  # disable CRC
         # disable auto_ack, dynamic payloads, all TX features, & auto-retry
         self._aa, self._dyn_pl, self._features, self._retry_setup = (0,) * 4
@@ -94,16 +96,6 @@ class FakeBLE(RF24):
         self._ble_name = None
         return super().__exit__()
 
-    @property
-    def to_android(self):
-        """A `bool` attribute to specify if advertisements should be
-        compatible with Android smartphones."""
-        return self._to_android == 0x42
-
-    @to_android.setter
-    def to_android(self, enable):
-        self._to_android = 0x42 if enable else 0x40
-
     @property
     def mac(self):
         """This attribute returns a 6-byte buffer that is used as the
@@ -138,7 +130,7 @@ class FakeBLE(RF24):
     @property
     def show_pa_level(self):
         """If this attribute is `True`, the payload will automatically include
-        the nRF24L01's `pa_level` in the advertisement."""
+        the nRF24L01's pa_level in the advertisement."""
         return bool(self._show_dbm)
 
     @show_pa_level.setter
@@ -153,7 +145,7 @@ class FakeBLE(RF24):
         self.channel = BLE_FREQ[self._curr_freq]
 
     def whiten(self, data):
-        """Whitening the BLE packet data ensures there's no long repetition
+        """Whitening the BLE packet data ensures there's no long repeatition
         of bits."""
         data, coef = (bytearray(data), (self._curr_freq + 37) | 0x40)
         for i, byte in enumerate(data):
@@ -169,14 +161,14 @@ class FakeBLE(RF24):
 
     def _make_payload(self, payload):
         """Assemble the entire packet to be transmitted as a payload."""
-        if self.available(payload) < 0:
+        if self.len_available(payload) < 0:
             raise ValueError(
                 "Payload length exceeds maximum buffer size by "
-                "{} bytes".format(abs(self.available(payload)))
+                "{} bytes".format(abs(self.len_available(payload)))
             )
         name_length = (len(self.name) + 2) if self.name is not None else 0
         pl_size = 9 + len(payload) + name_length + self._show_dbm * 3
-        buf = bytes([self._to_android, pl_size]) + self.mac
+        buf = bytes([0x42, pl_size]) + self.mac
         buf += chunk(b"\x05", 1)
         pa_level = b""
         if self._show_dbm:
@@ -188,15 +180,12 @@ class FakeBLE(RF24):
         buf += crc24_ble(buf)
         return buf
 
-    # pylint: disable=arguments-differ
-    # this overrides the RF24.available() for backward compatibility
-    def available(self, hypothetical=b""):
+    def len_available(self, hypothetical=b""):
         """This function will calculates how much length (in bytes) is
         available in the next payload."""
         name_length = (len(self.name) + 2) if self.name is not None else 0
         return 18 - name_length - self._show_dbm * 3 - len(hypothetical)
 
-    # pylint: enable=arguments-differ
     def advertise(self, buf=b"", data_type=0xFF):
         """This blocking function is used to broadcast a payload."""
         if not isinstance(buf, (bytearray, bytes, list, tuple)):
@@ -265,7 +254,7 @@ class FakeBLE(RF24):
         raise NotImplementedError("BLE implentation only uses 1 address")
 
     # pylint: enable=missing-function-docstring
-    def what_happened(self, dump_pipes=False):
+    def print_details(self, dump_pipes=False):
         """This debuggung function aggregates and outputs all status/condition
         related information from the nRF24L01."""
         print("Is a plus variant_________{}".format(self.is_plus_variant))
