@@ -25,7 +25,6 @@ __version__ = "0.0.0-auto.0"
 __repo__ = "https://github.com/2bndy5/CircuitPython_nRF24L01.git"
 import time
 from micropython import const
-
 try:
     from ubus_device import SPIDevice
 except ImportError:
@@ -54,11 +53,11 @@ def address_repr(addr):
 class RF24:
     """A driver class for the nRF24L01(+) transceiver radios."""
 
-    def __init__(self, spi, csn, ce, spi_frequency=10000000):
+    def __init__(self, spi, csn, ce_pin, spi_frequency=10000000):
         self._spi = SPIDevice(
-            spi, chip_select=csn, baudrate=spi_frequency, extra_clocks=8,
+            spi, chip_select=csn, baudrate=spi_frequency, extra_clocks=8
         )
-        self.ce_pin = ce
+        self.ce_pin = ce_pin
         self.ce_pin.switch_to_output(value=False)  # pre-empt standby-I mode
         self._status = 0  # status byte returned on all SPI transactions
         # pre-configure the CONFIGURE register:
@@ -68,6 +67,7 @@ class RF24:
         self._reg_write(CONFIGURE, self._config)
         if self._reg_read(CONFIGURE) & 3 != 2:
             raise RuntimeError("nRF24L01 Hardware not responding")
+        self.power = False
         # init shadow copy of RX addresses for all pipes for context manager
         self._pipes = [bytearray(5), bytearray(5), 0xC3, 0xC4, 0xC5, 0xC6]
         # _open_pipes attribute reflects only RX state on each pipe
@@ -97,7 +97,7 @@ class RF24:
         self._retry_setup = 0x53  # ard = 1500; arc = 3
         # pre-configure the RF_SETUP register
         self._rf_setup = 0x07  # 1 Mbps data_rate, and 0 dbm pa_level
-        # pre-configure dynamic_payloads & auto_ack for RX operations
+        # pre-configure dynamic_payloads & auto_ack
         self._dyn_pl = 0x3F  # 0x3F = enable dynamic_payloads on all pipes
         self._aa = 0x3F  # 0x3F = enable auto_ack on all pipes
         # pre-configure features for TX operations:
@@ -130,7 +130,8 @@ class RF24:
         self._reg_write_bytes(TX_ADDRESS, self._tx_address)
         self._reg_write(0x05, self._channel)
         self._reg_write(0x03, self._addr_len - 2)
-        self.payload_length = self._pl_len
+        for i, val in enumerate(self._pl_len):
+            self.set_payload_length(val, i)
         return self
 
     def __exit__(self, *exc):
@@ -272,7 +273,7 @@ class RF24:
             return self._pl_len[self.pipe]
         return 0
 
-    def recv(self, length=None):
+    def read(self, length=None):
         """This function is used to retrieve the next available payload in the
         RX FIFO buffer, then clears the `irq_dr` status flag."""
         return_size = length if length is not None else self.any()
@@ -304,7 +305,7 @@ class RF24:
                 if result is None or result:
                     break
         if self._status & 0x60 == 0x60 and not send_only:
-            result = self.recv()
+            result = self.read()
         return result
 
     @property
@@ -351,7 +352,7 @@ class RF24:
         self._config |= (not data_fail) << 4 | (not data_sent) << 5
         self._reg_write(CONFIGURE, self._config)
 
-    def what_happened(self, dump_pipes=False):
+    def print_details(self, dump_pipes=False):
         """This debuggung function aggregates and outputs all status/condition
         related information from the nRF24L01."""
         observer = self._reg_read(8)
@@ -473,19 +474,19 @@ class RF24:
 
     @property
     def dynamic_payloads(self):
-        """This `bool` attribute controls the nRF24L01's dynamic payload
-        length feature for each pipe."""
+        """This `int` attribute controls the nRF24L01's dynamic payload
+        length feature for any or all pipes."""
         self._dyn_pl = self._reg_read(DYN_PL_LEN)
-        self._features = self._reg_read(TX_FEATURE)
-        return bool(self._dyn_pl) and self._features & 4 == 4
+        return self._dyn_pl
 
     @dynamic_payloads.setter
     def dynamic_payloads(self, enable):
         self._features = self._reg_read(TX_FEATURE)
-        if isinstance(enable, (bool, int)):
+        if isinstance(enable, bool):
             self._dyn_pl = 0x3F if enable else 0
+        elif isinstance(enable, int):
+            self._dyn_pl = 0x3F & enable
         elif isinstance(enable, (list, tuple)):
-            self._dyn_pl = self._reg_read(DYN_PL_LEN)
             for i, val in enumerate(enable):
                 if i < 6 and val >= 0:  # skip pipe if val is negative
                     self._dyn_pl = (self._dyn_pl & ~(1 << i)) | (bool(val) << i)
@@ -501,12 +502,8 @@ class RF24:
         if pipe_number is None:
             self.dynamic_payloads = bool(enable)
         elif 0 <= pipe_number <= 5:
-            self._dyn_pl = self._reg_read(DYN_PL_LEN) & ~(1 << pipe_number)
-            self._dyn_pl |= (bool(enable) << pipe_number)
-            if self._dyn_pl:
-                self._features = (self._features & 3) | (bool(self._dyn_pl) << 2)
-                self._reg_write(TX_FEATURE, self._features)
-            self._reg_write(DYN_PL_LEN, self._dyn_pl)
+            self._dyn_pl &= ~(1 << pipe_number)
+            self.dynamic_payloads = self._dyn_pl | (bool(enable) << pipe_number)
         else:
             raise IndexError("pipe_number must be in range [0, 5]")
 
@@ -514,14 +511,13 @@ class RF24:
         """Returns a `bool` describing the setting of the dynamic payload
         feature about a specific data pipe."""
         if 0 <= pipe_number <= 5:
-            self._dyn_pl = self._reg_read(DYN_PL_LEN)
-            return bool(self._dyn_pl & (1 << pipe_number))
+            return bool(self.dynamic_payloads & (1 << pipe_number))
         raise IndexError("pipe_number must be in range [0, 5]")
 
     @property
     def payload_length(self):
-        """This `int` attribute specifies the length (in bytes) of static payloads for
-        any or all pipes."""
+        """This `int` attribute specifies the length (in bytes) of static
+        payloads for any or all pipes."""
         return self._pl_len[0]
 
     @payload_length.setter
@@ -546,7 +542,6 @@ class RF24:
     def get_payload_length(self, pipe_number=0):
         """Returns an `int` describing the current setting of a specified data
         pipe's expected static payload length."""
-        self._pl_len[pipe_number] = self._reg_read(RX_PL_LENG + pipe_number)
         return self._pl_len[pipe_number]
 
     @property
@@ -595,24 +590,25 @@ class RF24:
 
     @property
     def auto_ack(self):
-        """This `bool` attribute controls the nRF24L01's automatic
-        acknowledgment feature during the process of receiving a packet."""
+        """This `int` attribute controls the nRF24L01's automatic
+        acknowledgment feature for any or all pipes."""
         self._aa = self._reg_read(AUTO_ACK)
-        return bool(self._aa)
+        return self._aa
 
     @auto_ack.setter
     def auto_ack(self, enable):
-        if isinstance(enable, (bool, int)):
+        if isinstance(enable, bool):
             self._aa = 0x3F if enable else 0
+        elif isinstance(enable, int):
+            self._aa = 0x3F & enable
         elif isinstance(enable, (list, tuple)):
-            self._aa = self._reg_read(AUTO_ACK)
             for i, val in enumerate(enable):
                 if i < 6 and val >= 0:  # skip pipe if val is negative
                     self._aa = (self._aa & ~(1 << i)) | (bool(val) << i)
         else:
             raise ValueError("auto_ack: {} is not a valid input" % enable)
-        if self._aa & 1 != bool(self._aa & 0x3E) and self._aa & 0x3E:
-            self._aa |= 1
+        if bool(self._aa & 1) != bool(self._aa & 0x3E):
+            self._aa &= 1
         self._reg_write(AUTO_ACK, self._aa)
 
     def set_auto_ack(self, enable, pipe_number=None):
@@ -621,11 +617,8 @@ class RF24:
         if pipe_number is None:
             self.auto_ack = bool(enable)
         elif 0 <= pipe_number <= 5:
-            self._aa = self._reg_read(AUTO_ACK) & ~(1 << pipe_number)
-            self._aa |= (bool(enable) << pipe_number)
-            if pipe_number:
-                self._aa += 1
-            self._reg_write(AUTO_ACK, self._aa)
+            self._aa &= ~(1 << pipe_number)
+            self.auto_ack = self._aa | (bool(enable) << pipe_number)
         else:
             raise IndexError("pipe_number must be in range [0, 5]")
 
@@ -633,7 +626,6 @@ class RF24:
         """Returns a `bool` describing the automatic acknowledgement feature
         setting about a specific data pipe."""
         if 0 <= pipe_number <= 5:
-            self._aa = self._reg_read(AUTO_ACK)
             return bool(self._aa & (1 << pipe_number))
         raise IndexError("pipe_number must be in range [0, 5]")
 
@@ -649,11 +641,11 @@ class RF24:
 
     @ack.setter
     def ack(self, enable):
-        if self.ack != bool(enable):
-            self.auto_ack = (1,)
-            self._dyn_pl = self._dyn_pl & ~1 | 1
+        if bool(enable):
+            self.set_auto_ack(True, 0)
+            self._dyn_pl = self._dyn_pl & 0x3E | 1
             self._reg_write(DYN_PL_LEN, self._dyn_pl)
-            self._features |= 4
+            self._features = self._features | 4
         self._features = self._features & 5 | bool(enable) << 1
         self._reg_write(TX_FEATURE, self._features)
 
@@ -671,13 +663,9 @@ class RF24:
             return True
         return False
 
-    def read_ack(self):
-        """Allows user to read the automatic acknowledgement (ACK) payload (if any)."""
-        return self.recv()
-
     @property
     def allow_ask_no_ack(self):
-        """Enable or disable the use of ``ask_no_ack`` parameter to `send()` &
+        """Allow or disallow the use of ``ask_no_ack`` parameter to `send()` &
         `write()`."""
         self._features = self._reg_read(TX_FEATURE)
         return bool(self._features & 1)
@@ -733,7 +721,8 @@ class RF24:
 
     @crc.setter
     def crc(self, length):
-        length = (min(2, abs(int(length))) + 1) << 2 if length else 0
+        length = min(2, abs(int(length)))
+        length = (length + 1) << 2 if length else 0
         self._config = self._config & 0x73 | length
         self._reg_write(0, self._config)
 
@@ -797,7 +786,7 @@ class RF24:
             self.ce_pin.value = 0
             result = self.irq_ds
             if self._status & 0x60 == 0x60 and not send_only:
-                result = self.recv()
+                result = self.read()
         return result
 
     def write(self, buf, ask_no_ack=False, write_only=False):
