@@ -56,7 +56,7 @@ battery_service.data = 85
 
 
 def master(count=50):
-    """Sends out the device information."""
+    """Sends out the device information twice a second."""
     # using the "with" statement is highly recommended if the nRF24L01 is
     # to be used for more than a BLE configuration
     with nrf as ble:
@@ -65,10 +65,10 @@ def master(count=50):
         ble.show_pa_level = True
         print(
             "available bytes in next payload:",
-            ble.available(chunk(battery_service.buffer)),
+            ble.len_available(chunk(battery_service.buffer)),
         )  # using chunk() gives an accurate estimate of available bytes
         for i in range(count):  # advertise data this many times
-            if ble.available(chunk(battery_service.buffer)) >= 0:
+            if ble.len_available(chunk(battery_service.buffer)) >= 0:
                 _prompt(count - i)  # something to show that it isn't frozen
                 # broadcast the device name, MAC address, &
                 # battery charge info; 0x16 means service data
@@ -87,15 +87,15 @@ temperature_service.data = 42.0
 
 
 def send_temp(count=50):
-    """Sends out a fake temperature."""
+    """Sends out a fake temperature twice a second."""
     with nrf as ble:
         ble.name = b"nRF24L01"
         print(
             "available bytes in next payload:",
-            ble.available(chunk(temperature_service.buffer)),
+            ble.len_available(chunk(temperature_service.buffer)),
         )
         for i in range(count):
-            if ble.available(chunk(temperature_service.buffer)) >= 0:
+            if ble.len_available(chunk(temperature_service.buffer)) >= 0:
                 _prompt(count - i)
                 # broadcast a temperature measurement; 0x16 means service data
                 ble.advertise(temperature_service.buffer, data_type=0x16)
@@ -115,16 +115,16 @@ url_service.pa_level_at_1_meter = -45  # defaults to -25 dBm
 
 
 def send_url(count=50):
-    """Sends out a URL."""
+    """Sends out a URL twice a second."""
     with nrf as ble:
         print(
             "available bytes in next payload:",
-            ble.available(chunk(url_service.buffer)),
+            ble.len_available(chunk(url_service.buffer)),
         )
         # NOTE we did NOT set a device name in this with block
         for i in range(count):
             # URLs easily exceed the nRF24L01's max payload length
-            if ble.available(chunk(url_service.buffer)) >= 0:
+            if ble.len_available(chunk(url_service.buffer)) >= 0:
                 _prompt(count - i)
                 ble.advertise(url_service.buffer, 0x16)
                 ble.hop_channel()
